summaryrefslogtreecommitdiffstats
path: root/smb4k/core
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2583f299a84906ae6df2494a877553cbe3a7f804 (patch)
tree6b73a6bddd68796fbef5a8ca81ab4d136a5afe82 /smb4k/core
parent1b9ba97805fd4a187f1b8247c358feb823535b77 (diff)
downloadsmb4k-2583f299a84906ae6df2494a877553cbe3a7f804.tar.gz
smb4k-2583f299a84906ae6df2494a877553cbe3a7f804.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/smb4k@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'smb4k/core')
-rw-r--r--smb4k/core/smb4kbookmarkhandler.cpp4
-rw-r--r--smb4k/core/smb4kbookmarkhandler.h4
-rw-r--r--smb4k/core/smb4kfileio.cpp2
-rw-r--r--smb4k/core/smb4kfileio.h4
-rw-r--r--smb4k/core/smb4kglobal.cpp4
-rw-r--r--smb4k/core/smb4kglobal.h4
-rw-r--r--smb4k/core/smb4khomesshareshandler.cpp8
-rw-r--r--smb4k/core/smb4khomesshareshandler.h8
-rw-r--r--smb4k/core/smb4kmounter.cpp2
-rw-r--r--smb4k/core/smb4kmounter.h2
-rw-r--r--smb4k/core/smb4kpasswordhandler.cpp12
-rw-r--r--smb4k/core/smb4kpasswordhandler.h12
-rw-r--r--smb4k/core/smb4kpreviewer.cpp4
-rw-r--r--smb4k/core/smb4kpreviewer.h4
-rw-r--r--smb4k/core/smb4kprint.cpp2
-rw-r--r--smb4k/core/smb4kprint.h2
-rw-r--r--smb4k/core/smb4ksambaoptionshandler.cpp8
-rw-r--r--smb4k/core/smb4ksambaoptionshandler.h4
-rw-r--r--smb4k/core/smb4kscanner.cpp4
-rw-r--r--smb4k/core/smb4kscanner.h4
-rw-r--r--smb4k/core/smb4ksettings.cpp8
-rw-r--r--smb4k/core/smb4ksynchronizer.cpp4
-rw-r--r--smb4k/core/smb4ksynchronizer.h4
23 files changed, 57 insertions, 57 deletions
diff --git a/smb4k/core/smb4kbookmarkhandler.cpp b/smb4k/core/smb4kbookmarkhandler.cpp
index 6d5d253..26215b8 100644
--- a/smb4k/core/smb4kbookmarkhandler.cpp
+++ b/smb4k/core/smb4kbookmarkhandler.cpp
@@ -48,8 +48,8 @@ using namespace Smb4KGlobal;
Smb4KBookmarkHandler::Smb4KBookmarkHandler( TQValueList<Smb4KHostItem *> *hosts,
-TQObject *tqparent, const char *name )
-: TQObject( tqparent, name ), m_hosts( hosts )
+TQObject *parent, const char *name )
+: TQObject( parent, name ), m_hosts( hosts )
{
// First we need the directory.
KStandardDirs *stddir = new KStandardDirs();
diff --git a/smb4k/core/smb4kfileio.cpp b/smb4k/core/smb4kfileio.cpp
index 64cf608..9b42709 100644
--- a/smb4k/core/smb4kfileio.cpp
+++ b/smb4k/core/smb4kfileio.cpp
@@ -54,7 +54,7 @@ using namespace Smb4KGlobal;
-Smb4KFileIO::Smb4KFileIO( TQObject *tqparent, const char *name ) : TQObject( tqparent, name )
+Smb4KFileIO::Smb4KFileIO( TQObject *parent, const char *name ) : TQObject( parent, name )
{
m_operation = NoOperation;
m_state = Idle;
diff --git a/smb4k/core/smb4kglobal.cpp b/smb4k/core/smb4kglobal.cpp
index 4c1fa0c..a4d27f0 100644
--- a/smb4k/core/smb4kglobal.cpp
+++ b/smb4k/core/smb4kglobal.cpp
@@ -48,9 +48,9 @@ const int Smb4KGlobal::timerInterval()
}
-const TQString Smb4KGlobal::specifyUser( const TQString &host, TQWidget *tqparent, const char *name )
+const TQString Smb4KGlobal::specifyUser( const TQString &host, TQWidget *parent, const char *name )
{
- return p.homesHandler()->specifyUser( host, tqparent, name );
+ return p.homesHandler()->specifyUser( host, parent, name );
}
diff --git a/smb4k/core/smb4khomesshareshandler.cpp b/smb4k/core/smb4khomesshareshandler.cpp
index 35fdb2a..392581c 100644
--- a/smb4k/core/smb4khomesshareshandler.cpp
+++ b/smb4k/core/smb4khomesshareshandler.cpp
@@ -42,8 +42,8 @@
#include "smb4kerror.h"
-Smb4KHomesSharesHandler::Smb4KHomesSharesHandler( TQObject *tqparent, const char *name )
-: TQObject( tqparent, name )
+Smb4KHomesSharesHandler::Smb4KHomesSharesHandler( TQObject *parent, const char *name )
+: TQObject( parent, name )
{
// First we need the directory.
KStandardDirs *stddir = new KStandardDirs();
@@ -66,11 +66,11 @@ Smb4KHomesSharesHandler::~Smb4KHomesSharesHandler()
}
-const TQString Smb4KHomesSharesHandler::specifyUser( const TQString &host, TQWidget *tqparent, const char *name )
+const TQString Smb4KHomesSharesHandler::specifyUser( const TQString &host, TQWidget *parent, const char *name )
{
TQString username = TQString();
- m_dlg = new KDialogBase( KDialogBase::Plain, i18n( "Specify User" ), KDialogBase::User1|KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, tqparent, name, true, true );
+ m_dlg = new KDialogBase( KDialogBase::Plain, i18n( "Specify User" ), KDialogBase::User1|KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, parent, name, true, true );
m_dlg->setButtonGuiItem( KDialogBase::User1, KGuiItem( i18n( "Clear List" ), "editdelete", 0, 0 ) );
m_dlg->enableButton( KDialogBase::Ok, false );
m_dlg->enableButton( KDialogBase::User1, false );
diff --git a/smb4k/core/smb4kmounter.cpp b/smb4k/core/smb4kmounter.cpp
index e12b30a..ccf687d 100644
--- a/smb4k/core/smb4kmounter.cpp
+++ b/smb4k/core/smb4kmounter.cpp
@@ -73,7 +73,7 @@
using namespace Smb4KGlobal;
-Smb4KMounter::Smb4KMounter( TQObject *tqparent, const char *name ) : TQObject( tqparent, name )
+Smb4KMounter::Smb4KMounter( TQObject *parent, const char *name ) : TQObject( parent, name )
{
m_priv = new Smb4KMounterPrivate;
diff --git a/smb4k/core/smb4kmounter.h b/smb4k/core/smb4kmounter.h
index be29116..cfb41cc 100644
--- a/smb4k/core/smb4kmounter.h
+++ b/smb4k/core/smb4kmounter.h
@@ -65,7 +65,7 @@ class Smb4KMounter : public TQObject
/**
* The constructor.
*/
- Smb4KMounter( TQObject *tqparent = 0, const char *name = 0 );
+ Smb4KMounter( TQObject *parent = 0, const char *name = 0 );
/**
* The destructor.
*/
diff --git a/smb4k/core/smb4kpasswordhandler.cpp b/smb4k/core/smb4kpasswordhandler.cpp
index 2b7e6ff..e3624ee 100644
--- a/smb4k/core/smb4kpasswordhandler.cpp
+++ b/smb4k/core/smb4kpasswordhandler.cpp
@@ -60,11 +60,11 @@
#ifndef __FreeBSD__
-Smb4KPasswordHandler::Smb4KPasswordHandler( Smb4KHomesSharesHandler *handler, TQObject *tqparent, const char *name )
-: TQObject( tqparent, name ), m_handler( handler ), m_wallet_support_disabled( false )
+Smb4KPasswordHandler::Smb4KPasswordHandler( Smb4KHomesSharesHandler *handler, TQObject *parent, const char *name )
+: TQObject( parent, name ), m_handler( handler ), m_wallet_support_disabled( false )
#else
-Smb4KPasswordHandler::Smb4KPasswordHandler( Smb4KHomesSharesHandler *s_handler, Smb4KSambaOptionsHandler *o_handler, TQObject *tqparent, const char *name )
-: TQObject( tqparent, name ), m_handler( s_handler ), m_options_handler( o_handler ),
+Smb4KPasswordHandler::Smb4KPasswordHandler( Smb4KHomesSharesHandler *s_handler, Smb4KSambaOptionsHandler *o_handler, TQObject *parent, const char *name )
+: TQObject( parent, name ), m_handler( s_handler ), m_options_handler( o_handler ),
m_wallet_support_disabled( false )
#endif
{
@@ -228,14 +228,14 @@ void Smb4KPasswordHandler::convert_old_entries()
}
-bool Smb4KPasswordHandler::askpass( const TQString &workgroup, const TQString &host, const TQString &share, int desc, TQWidget *tqparent, const char *name )
+bool Smb4KPasswordHandler::askpass( const TQString &workgroup, const TQString &host, const TQString &share, int desc, TQWidget *parent, const char *name )
{
// m_auth is NULL:
m_auth = readAuth( new Smb4KAuthInfo( workgroup, host, share ) );
// Set up the askpass dialog:
m_dlg = new KDialogBase( KDialogBase::Plain, i18n( "Authentication" ), KDialogBase::Ok|KDialogBase::Cancel,
- KDialogBase::Ok, tqparent, name, true, true );
+ KDialogBase::Ok, parent, name, true, true );
TQFrame *frame = m_dlg->plainPage();
TQGridLayout *tqlayout = new TQGridLayout( frame );
diff --git a/smb4k/core/smb4kpreviewer.cpp b/smb4k/core/smb4kpreviewer.cpp
index 6d76f8f..1ddff6f 100644
--- a/smb4k/core/smb4kpreviewer.cpp
+++ b/smb4k/core/smb4kpreviewer.cpp
@@ -43,8 +43,8 @@
using namespace Smb4KGlobal;
-Smb4KPreviewer::Smb4KPreviewer( TQObject *tqparent, const char *name )
-: TQObject( tqparent, name )
+Smb4KPreviewer::Smb4KPreviewer( TQObject *parent, const char *name )
+: TQObject( parent, name )
{
m_item = NULL;
diff --git a/smb4k/core/smb4kprint.cpp b/smb4k/core/smb4kprint.cpp
index 76e4a9a..b3672d3 100644
--- a/smb4k/core/smb4kprint.cpp
+++ b/smb4k/core/smb4kprint.cpp
@@ -50,7 +50,7 @@ using namespace Smb4KGlobal;
-Smb4KPrint::Smb4KPrint( TQObject *tqparent, const char *name ) : TQObject( tqparent, name )
+Smb4KPrint::Smb4KPrint( TQObject *parent, const char *name ) : TQObject( parent, name )
{
m_proc = new KProcess( this, "PrintProcess" );
m_proc->setUseShell( true );
diff --git a/smb4k/core/smb4kprint.h b/smb4k/core/smb4kprint.h
index 2f75de2..13b8059 100644
--- a/smb4k/core/smb4kprint.h
+++ b/smb4k/core/smb4kprint.h
@@ -61,7 +61,7 @@ class Smb4KPrint : public TQObject
/**
* The constructor.
*/
- Smb4KPrint( TQObject *tqparent = 0, const char *name = 0 );
+ Smb4KPrint( TQObject *parent = 0, const char *name = 0 );
/**
* The destructor.
diff --git a/smb4k/core/smb4ksambaoptionshandler.cpp b/smb4k/core/smb4ksambaoptionshandler.cpp
index acd2d82..b7d145f 100644
--- a/smb4k/core/smb4ksambaoptionshandler.cpp
+++ b/smb4k/core/smb4ksambaoptionshandler.cpp
@@ -51,8 +51,8 @@
using namespace Smb4KGlobal;
-Smb4KSambaOptionsHandler::Smb4KSambaOptionsHandler( TQObject *tqparent, const char *name )
-: TQObject( tqparent, name )
+Smb4KSambaOptionsHandler::Smb4KSambaOptionsHandler( TQObject *parent, const char *name )
+: TQObject( parent, name )
{
// We need the directory.
KStandardDirs *stddir = new KStandardDirs();
@@ -1285,11 +1285,11 @@ const TQString Smb4KSambaOptionsHandler::mountOptions( const TQString &share )
TQString() );
args.append( !Smb4KSettings::fileMask().isEmpty() ?
- TQString( "ftqmask=%1," ).tqarg( Smb4KSettings::fileMask() ) :
+ TQString( "fmask=%1," ).tqarg( Smb4KSettings::fileMask() ) :
TQString() );
args.append( !Smb4KSettings::directoryMask().isEmpty() ?
- TQString( "dtqmask=%1," ).tqarg( Smb4KSettings::directoryMask() ) :
+ TQString( "dmask=%1," ).tqarg( Smb4KSettings::directoryMask() ) :
TQString() );
args.append( kerberos ? "krb," : TQString() );
diff --git a/smb4k/core/smb4kscanner.cpp b/smb4k/core/smb4kscanner.cpp
index f9d3021..c70aec7 100644
--- a/smb4k/core/smb4kscanner.cpp
+++ b/smb4k/core/smb4kscanner.cpp
@@ -56,8 +56,8 @@ static bool created_hosts_list = false;
Smb4KScanner::Smb4KScanner( TQValueList<Smb4KWorkgroupItem *> *workgroups, TQValueList<Smb4KHostItem *> *hosts,
-TQObject *tqparent, const char *name )
-: TQObject( tqparent, name ), m_workgroups_list( workgroups ), m_hosts_list( hosts )
+TQObject *parent, const char *name )
+: TQObject( parent, name ), m_workgroups_list( workgroups ), m_hosts_list( hosts )
{
m_priv = new Smb4KScannerPrivate;
diff --git a/smb4k/core/smb4ksettings.cpp b/smb4k/core/smb4ksettings.cpp
index 92aa79b..098c6a5 100644
--- a/smb4k/core/smb4ksettings.cpp
+++ b/smb4k/core/smb4ksettings.cpp
@@ -666,12 +666,12 @@ Smb4KSettings::Smb4KSettings( )
mGroupIDItem->setWhatsThis( i18n("Here you can enter the group ID (a number) that the files and directories of the mounted share will have. If you are using the CIFS file system and the remote server supports the CIFS Unix Extentions, this setting will be ignored.") );
addItem( mGroupIDItem, TQString::tqfromLatin1( "GroupID" ) );
mFileMaskItem = new KConfigSkeleton::ItemString( currentGroup(), TQString::tqfromLatin1( "FileMask" ), mFileMask, TQString::tqfromLatin1( "0755" ) );
- mFileMaskItem->setLabel( i18n("The file tqmask for a share") );
- mFileMaskItem->setWhatsThis( i18n("This is the tqmask that will be used for creating files. It must be defined in octal. In case the CIFS file system is used, this setting only takes effect if the server does not support the CIFS Unix Extensions.") );
+ mFileMaskItem->setLabel( i18n("The file mask for a share") );
+ mFileMaskItem->setWhatsThis( i18n("This is the mask that will be used for creating files. It must be defined in octal. In case the CIFS file system is used, this setting only takes effect if the server does not support the CIFS Unix Extensions.") );
addItem( mFileMaskItem, TQString::tqfromLatin1( "FileMask" ) );
mDirectoryMaskItem = new KConfigSkeleton::ItemString( currentGroup(), TQString::tqfromLatin1( "DirectoryMask" ), mDirectoryMask, TQString::tqfromLatin1( "0755" ) );
- mDirectoryMaskItem->setLabel( i18n("The directory tqmask for a share") );
- mDirectoryMaskItem->setWhatsThis( i18n("This is the tqmask that will be used for creating directories. It must be defined in octal. In case the CIFS file system is used, this setting only takes effect if the server does not support the CIFS Unix Extensions.") );
+ mDirectoryMaskItem->setLabel( i18n("The directory mask for a share") );
+ mDirectoryMaskItem->setWhatsThis( i18n("This is the mask that will be used for creating directories. It must be defined in octal. In case the CIFS file system is used, this setting only takes effect if the server does not support the CIFS Unix Extensions.") );
addItem( mDirectoryMaskItem, TQString::tqfromLatin1( "DirectoryMask" ) );
TQValueList<KConfigSkeleton::ItemEnum::Choice> valuesWriteAccess;
{
diff --git a/smb4k/core/smb4ksynchronizer.cpp b/smb4k/core/smb4ksynchronizer.cpp
index 8944157..819ad79 100644
--- a/smb4k/core/smb4ksynchronizer.cpp
+++ b/smb4k/core/smb4ksynchronizer.cpp
@@ -54,8 +54,8 @@ using namespace Smb4KGlobal;
bool cancel = false;
-Smb4KSynchronizer::Smb4KSynchronizer( TQObject *tqparent, const char *name )
-: TQObject( tqparent, name )
+Smb4KSynchronizer::Smb4KSynchronizer( TQObject *parent, const char *name )
+: TQObject( parent, name )
{
m_proc = new KProcess( this, "SynchronizerProcess" );
diff --git a/smb4k/core/smb4kbookmarkhandler.h b/smb4k/core/smb4kbookmarkhandler.h
index 4e4f29f..07f75eb 100644
--- a/smb4k/core/smb4kbookmarkhandler.h
+++ b/smb4k/core/smb4kbookmarkhandler.h
@@ -61,12 +61,12 @@ class Smb4KBookmarkHandler : public TQObject
* In case a NULL pointer is passed, the bookmarks won't
* be updated.
*
* @param tqparent The tqparent of this object
*
* @param name This object's name
*/
Smb4KBookmarkHandler( TQValueList<Smb4KHostItem *> *hosts = 0,
- TQObject *tqparent = 0,
+ TQObject *parent = 0,
const char *name = 0 );
/**
@@ -61,12 +61,12 @@ class Smb4KBookmarkHandler : public TQObject
* be updated.
*
- * @param tqparent The tqparent of this object
+ * @param parent The parent of this object
*
* @param name This object's name
diff --git a/smb4k/core/smb4kfileio.h b/smb4k/core/smb4kfileio.h
index 496593c..ba253aa 100644
--- a/smb4k/core/smb4kfileio.h
+++ b/smb4k/core/smb4kfileio.h
@@ -55,11 +55,11 @@ class Smb4KFileIO : public TQObject
/**
* The constructor
*
* @param tqparent The tqparent object of this class
*
* @param name The name of this class
*/
- Smb4KFileIO( TQObject *tqparent = 0, const char *name = 0 );
+ Smb4KFileIO( TQObject *parent = 0, const char *name = 0 );
/**
* The destructor
@@ -55,11 +55,11 @@ class Smb4KFileIO : public TQObject
* The constructor
*
- * @param tqparent The tqparent object of this class
+ * @param parent The parent object of this class
*
* @param name The name of this class
diff --git a/smb4k/core/smb4kglobal.h b/smb4k/core/smb4kglobal.h
index db6d4c0..1efe779 100644
--- a/smb4k/core/smb4kglobal.h
+++ b/smb4k/core/smb4kglobal.h
@@ -67,13 +67,13 @@ namespace Smb4KGlobal
*
* @param host The host where the homes share is located
*
* @param tqparent The tqparent widget
*
* @param name The name of this dialog
*
* @returns A user name
*/
- const TQString specifyUser( const TQString &host, TQWidget *tqparent = 0, const char *name = 0 );
+ const TQString specifyUser( const TQString &host, TQWidget *parent = 0, const char *name = 0 );
/**
* This function returns the password handler.
@@ -67,13 +67,13 @@ namespace Smb4KGlobal
* @param host The host where the homes share is located
*
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
*
* @param name The name of this dialog
diff --git a/smb4k/core/smb4khomesshareshandler.h b/smb4k/core/smb4khomesshareshandler.h
index 4db96f7..aee4568 100644
--- a/smb4k/core/smb4khomesshareshandler.h
+++ b/smb4k/core/smb4khomesshareshandler.h
@@ -54,11 +54,11 @@ class Smb4KHomesSharesHandler : public TQObject
/**
* The constructor
*
* @param tqparent The tqparent object of this class
*
* @param name The name of this class
*/
- Smb4KHomesSharesHandler( TQObject *tqparent = 0, const char *name = 0 );
+ Smb4KHomesSharesHandler( TQObject *parent = 0, const char *name = 0 );
/**
* The destructor
@@ -72,13 +72,13 @@ class Smb4KHomesSharesHandler : public TQObject
*
* @param host The host where the homes share is located
*
* @param tqparent The tqparent widget
*
* @param name The name of this dialog
*
* @returns A user name
*/
- const TQString specifyUser( const TQString &host, TQWidget *tqparent = 0, const char *name = 0 );
+ const TQString specifyUser( const TQString &host, TQWidget *parent = 0, const char *name = 0 );
/**
* Read and return the user names that are defined for a homes share.
@@ -54,11 +54,11 @@ class Smb4KHomesSharesHandler : public TQObject
* The constructor
*
- * @param tqparent The tqparent object of this class
+ * @param parent The parent object of this class
*
* @param name The name of this class
@@ -72,13 +72,13 @@ class Smb4KHomesSharesHandler : public TQObject
* @param host The host where the homes share is located
*
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
*
* @param name The name of this dialog
diff --git a/smb4k/core/smb4kpasswordhandler.h b/smb4k/core/smb4kpasswordhandler.h
index 744aa15..8898249 100644
--- a/smb4k/core/smb4kpasswordhandler.h
+++ b/smb4k/core/smb4kpasswordhandler.h
@@ -76,12 +76,12 @@ class Smb4KPasswordHandler : public TQObject
* infos in case we need to look up authentication information for
* 'homes' shares.
*
* @param tqparent The tqparent object.
*
* @param name The name this class should carry.
*/
Smb4KPasswordHandler( Smb4KHomesSharesHandler *handler,
- TQObject *tqparent = 0,
+ TQObject *parent = 0,
const char *name = 0 );
#else
/**
@@ -94,13 +94,13 @@ class Smb4KPasswordHandler : public TQObject
* @param o_handler The Smb4KSambaOptionsHandler object. It is needed to write the
* ~/.nsmbrc file correctly.
*
* @param tqparent The tqparent object.
*
* @param name The name this class should carry.
*/
Smb4KPasswordHandler( Smb4KHomesSharesHandler *s_handler,
Smb4KSambaOptionsHandler *o_handler,
- TQObject *tqparent = 0,
+ TQObject *parent = 0,
const char *name = 0 );
#endif
@@ -122,13 +122,13 @@ class Smb4KPasswordHandler : public TQObject
* Values are taken from the Smb4KPasswordHandler::AskPass::Description
* enumeration.
*
* @param tqparent The tqparent of this dialog.
*
* @param name The name of this dialog.
*
* @returns TRUE if a new password has been supplied and FALSE otherwise.
*/
- bool askpass( const TQString &workgroup, const TQString &host, const TQString &share, int desc, TQWidget *tqparent = 0, const char *name = 0 );
+ bool askpass( const TQString &workgroup, const TQString &host, const TQString &share, int desc, TQWidget *parent = 0, const char *name = 0 );
/**
* Returns the authentication data that was found for the defined share. You need to
@@ -76,12 +76,12 @@ class Smb4KPasswordHandler : public TQObject
* 'homes' shares.
*
- * @param tqparent The tqparent object.
+ * @param parent The parent object.
*
* @param name The name this class should carry.
@@ -94,13 +94,13 @@ class Smb4KPasswordHandler : public TQObject
* ~/.nsmbrc file correctly.
*
- * @param tqparent The tqparent object.
+ * @param parent The parent object.
*
* @param name The name this class should carry.
@@ -122,13 +122,13 @@ class Smb4KPasswordHandler : public TQObject
* enumeration.
*
- * @param tqparent The tqparent of this dialog.
+ * @param parent The parent of this dialog.
*
* @param name The name of this dialog.
diff --git a/smb4k/core/smb4kpreviewer.h b/smb4k/core/smb4kpreviewer.h
index bc99ca8..2ae55a2 100644
--- a/smb4k/core/smb4kpreviewer.h
+++ b/smb4k/core/smb4kpreviewer.h
@@ -57,11 +57,11 @@ class Smb4KPreviewer : public TQObject
/**
* The constructor
*
* @param tqparent The tqparent object
*
* @param name The name of this object
*/
- Smb4KPreviewer( TQObject *tqparent = 0, const char *name = 0 );
+ Smb4KPreviewer( TQObject *parent = 0, const char *name = 0 );
/**
* The destructor
@@ -57,11 +57,11 @@ class Smb4KPreviewer : public TQObject
* The constructor
*
- * @param tqparent The tqparent object
+ * @param parent The parent object
*
* @param name The name of this object
diff --git a/smb4k/core/smb4ksambaoptionshandler.h b/smb4k/core/smb4ksambaoptionshandler.h
index d14f0fb..a0e833a 100644
--- a/smb4k/core/smb4ksambaoptionshandler.h
+++ b/smb4k/core/smb4ksambaoptionshandler.h
@@ -58,11 +58,11 @@ class Smb4KSambaOptionsHandler : public TQObject
/**
* The constructor
*
* @param tqparent The tqparent object
*
* @param name The name of this object
*/
- Smb4KSambaOptionsHandler( TQObject *tqparent = 0, const char *name = 0 );
+ Smb4KSambaOptionsHandler( TQObject *parent = 0, const char *name = 0 );
/**
* The destructor
@@ -58,11 +58,11 @@ class Smb4KSambaOptionsHandler : public TQObject
* The constructor
*
- * @param tqparent The tqparent object
+ * @param parent The parent object
*
* @param name The name of this object
diff --git a/smb4k/core/smb4kscanner.h b/smb4k/core/smb4kscanner.h
index 4a5f4ad..1d9f1a3 100644
--- a/smb4k/core/smb4kscanner.h
+++ b/smb4k/core/smb4kscanner.h
@@ -72,13 +72,13 @@ class Smb4KScanner : public TQObject
* with the list of available hosts. If a NULL pointer is passed, a
* private list will be created which cannot be accessed from outside.
*
* @param tqparent The tqparent of this class.
*
* @param name The name of this class.
*/
Smb4KScanner( TQValueList<Smb4KWorkgroupItem *> *workgroups = 0,
TQValueList<Smb4KHostItem *> *hosts = 0,
- TQObject *tqparent = 0,
+ TQObject *parent = 0,
const char *name = 0 );
/**
@@ -72,13 +72,13 @@ class Smb4KScanner : public TQObject
* private list will be created which cannot be accessed from outside.
*
- * @param tqparent The tqparent of this class.
+ * @param parent The parent of this class.
*
* @param name The name of this class.
diff --git a/smb4k/core/smb4ksynchronizer.h b/smb4k/core/smb4ksynchronizer.h
index 1bce096..298343e 100644
--- a/smb4k/core/smb4ksynchronizer.h
+++ b/smb4k/core/smb4ksynchronizer.h
@@ -60,11 +60,11 @@ class Smb4KSynchronizer : public TQObject
/**
* The constructor of the synchronizer.
*
* @param tqparent The tqparent of this object
*
* @param name The name of this object
*/
- Smb4KSynchronizer( TQObject *tqparent = 0, const char *name = 0 );
+ Smb4KSynchronizer( TQObject *parent = 0, const char *name = 0 );
/**
* The destructor.
@@ -60,11 +60,11 @@ class Smb4KSynchronizer : public TQObject
* The constructor of the synchronizer.
*
- * @param tqparent The tqparent of this object
+ * @param parent The parent of this object
*
* @param name The name of this object